==> igniteui-react-charts-16.6.4.tgz: package/ES2015/PolarLineSeries_combined.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { PolarLineSeriesBase } from "./PolarLineSeriesBase";
import { UnknownValuePlotting_$type } from "igniteui-react-core/ES2015/UnknownValuePlotting";
import { DependencyProperty } from "igniteui-react-core/ES2015/DependencyProperty";
import { Type, enumGetBox, markType } from "igniteui-react-core/ES2015/type";
import { PropertyMetadata } from "igniteui-react-core/ES2015/PropertyMetadata";
import { PolarLineSeriesBaseView } from "./PolarLineSeriesBaseView";
import { Path } from "igniteui-react-core/ES2015/Path";
export class PolarLineSeries extends PolarLineSeriesBase {
    constructor() {
        super();
        this.ab = PolarLineSeries.$;
    }
    bf() {
        return new PolarLineSeriesView(this);
    }
    il(a) {
        super.il(a);
        this.o4 = a;
    }
    o2(a) {
        let b = a;
        b.c0();
    }
    o3(a, b) {
        let c = b;
        c.c1(a.m, this.eq);
    }
    ou() {
        return this.o5;
    }
    ir(a, b, c, d) {
        super.ir(a, b, c, d);
        switch (b) {
            case PolarLineSeries.$$p[0]:
                this.i4(false);
                this.ib();
                break;
        }
    }
}
PolarLineSeries.$t = markType(PolarLineSeries, 'PolarLineSeries', PolarLineSeriesBase.$);
Type.dep(DependencyProperty, PropertyMetadata, PolarLineSeries, 'raisePropertyChanged', ['UnknownValuePlotting:o5:o7', [UnknownValuePlotting_$type, enumGetBox(UnknownValuePlotting_$type, 1)]]);
export class PolarLineSeriesView extends PolarLineSeriesBaseView {
    constructor(a) {
        super(a);
        this.cz = null;
        this.c2 = new Path();
        this.cz = a;
    }
    ap() {
        super.ap();
    }
    c0() {
        this.c2.aj = null;
        this.an();
    }
    c1(a, b) {
        this.cz.or.d(this.c2, a, b);
        this.an();
    }
    a8() {
        super.a8();
        this.c2._stroke = this.e.ku;
        this.c2.ac = this.e.eu;
        this.c2.ai = this.e.k2;
        this.c2.ad = this.e.k3;
    }
    a9() {
        super.a9();
        let a = this.bl();
        this.c2._stroke = a;
        this.c2.ac = this.e.eu + 3;
    }
    a3(a, b) {
        super.a3(a, b);
        a.s(this.c2);
    }
    ai(a) {
        super.ai(a);
        this.e.a2.exportPathData(a, this.c2, "polarShape", ["Main"]);
    }
}
PolarLineSeriesView.$t = markType(PolarLineSeriesView, 'PolarLineSeriesView', PolarLineSeriesBaseView.$);

==> igniteui-react-charts-16.6.8.tgz: package/ES2015/PolarLineSeries_combined.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { PolarLineSeriesBase } from "./PolarLineSeriesBase";
import { UnknownValuePlotting_$type } from "igniteui-react-core/ES2015/UnknownValuePlotting";
import { DependencyProperty } from "igniteui-react-core/ES2015/DependencyProperty";
import { Type, enumGetBox, markType } from "igniteui-react-core/ES2015/type";
import { PropertyMetadata } from "igniteui-react-core/ES2015/PropertyMetadata";
import { PolarLineSeriesBaseView } from "./PolarLineSeriesBaseView";
import { Path } from "igniteui-react-core/ES2015/Path";
/**
 * @hidden
 */
export class PolarLineSeries extends PolarLineSeriesBase {
    constructor() {
        super();
        this.ab = PolarLineSeries.$;
    }
    bf() {
        return new PolarLineSeriesView(this);
    }
    im(a) {
        super.im(a);
        this.o6 = a;
    }
    o4(a) {
        let b = a;
        b.c0();
    }
    o5(a, b) {
        let c = b;
        c.c1(a.m, this.er);
    }
    ow() {
        return this.o7;
    }
    is(a, b, c, d) {
        super.is(a, b, c, d);
        switch (b) {
            case PolarLineSeries.$$p[0]:
                this.i6(false);
                this.ic();
                break;
        }
    }
}
PolarLineSeries.$t = markType(PolarLineSeries, 'PolarLineSeries', PolarLineSeriesBase.$);
Type.dep(DependencyProperty, PropertyMetadata, PolarLineSeries, 'raisePropertyChanged', ['UnknownValuePlotting:o7:o9', [UnknownValuePlotting_$type, enumGetBox(UnknownValuePlotting_$type, 1)]]);
/**
 * @hidden
 */
export class PolarLineSeriesView extends PolarLineSeriesBaseView {
    constructor(a) {
        super(a);
        this.cz = null;
        this.c2 = new Path();
        this.cz = a;
    }
    ap() {
        super.ap();
    }
    c0() {
        this.c2.aj = null;
        this.an();
    }
    c1(a, b) {
        this.cz.ot.d(this.c2, a, b);
        this.an();
    }
    a8() {
        super.a8();
        this.c2._stroke = this.e.kw;
        this.c2.ac = this.e.ev;
        this.c2.ai = this.e.k4;
        this.c2.ad = this.e.k5;
    }
    a9() {
        super.a9();
        let a = this.bl();
        this.c2._stroke = a;
        this.c2.ac = this.e.ev + 3;
    }
    a3(a, b) {
        super.a3(a, b);
        a.s(this.c2);
    }
    ai(a) {
        super.ai(a);
        this.e.a2.exportPathData(a, this.c2, "polarShape", ["Main"]);
    }
}
PolarLineSeriesView.$t = markType(PolarLineSeriesView, 'PolarLineSeriesView', PolarLineSeriesBaseView.$);
